%{?mingw_package_header}

Name:           mingw-gnutls
Version:        3.8.7
Release:        %mkrel 2
Summary:        MinGW GnuTLS TLS/SSL encryption library

# The libraries are LGPLv2.1+, utilities are GPLv3+
License:        GPLv3+ and LGPLv2+
Group:          Development/Other
URL:            https://www.gnutls.org/
%define short_version %(echo %{version} | grep -m1 -o "[0-9]*\.[0-9]*" | head -1)
Source0:        https://www.gnupg.org/ftp/gcrypt/gnutls/v%{short_version}/gnutls-%{version}.tar.xz
Source1:        https://www.gnupg.org/ftp/gcrypt/gnutls/v%{short_version}/gnutls-%{version}.tar.xz.sig
Source2:        gnutls-release-keyring.gpg

BuildArch:      noarch

BuildRequires:  make
BuildRequires:  mingw32-cpp
BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-libtasn1 >= 4.3
BuildRequires:  mingw32-readline
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-nettle >= 3.6

BuildRequires:  mingw64-cpp
BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-libtasn1 >= 4.3
BuildRequires:  mingw64-readline
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-nettle >= 3.6

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  byacc
BuildRequires:  gnupg2
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  git

# Yes, really ...
BuildRequires:  pkgconfig

# For native /usr/bin/msgfmt etc.
BuildRequires:  gettext-devel


%description
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.


# Win32
%package -n mingw32-gnutls
Summary:        MinGW GnuTLS TLS/SSL encryption library
Requires:       pkgconfig
Requires:       mingw32-libtasn1 >= 4.3

%description -n mingw32-gnutls
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.

# Win64
%package -n mingw64-gnutls
Summary:        MinGW GnuTLS TLS/SSL encryption library
Requires:       pkgconfig
Requires:       mingw64-libtasn1 >= 4.3

%description -n mingw64-gnutls
GnuTLS TLS/SSL encryption library.  This library is cross-compiled
for MinGW.


%{?mingw_debug_package}


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -S git -n gnutls-%{version}

rm -f lib/minitasn1/*.c lib/minitasn1/*.h

%build
export CCASFLAGS=""
%mingw_configure \
    --enable-sha1-support \
    --disable-static \
    --disable-openssl-compatibility \
    --disable-non-suiteb-curves \
    --disable-libdane \
    --disable-rpath \
    --disable-nls \
    --disable-cxx \
    --enable-shared \
    --without-tpm \
    --with-included-unistring \
    --disable-doc \
    --with-default-priority-string="@SYSTEM" \
    --without-p11-kit
%mingw_make_build


%install
%mingw_make_install

# Remove .la files
rm -f $RPM_BUILD_ROOT%{mingw32_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{mingw64_libdir}/*.la

# The .def files aren't interesting for other binaries
rm -f $RPM_BUILD_ROOT%{mingw32_bindir}/*.def
rm -f $RPM_BUILD_ROOT%{mingw64_bindir}/*.def

# Remove info and man pages which duplicate stuff in Fedora already.
rm -rf $RPM_BUILD_ROOT%{mingw32_infodir}
rm -rf $RPM_BUILD_ROOT%{mingw32_mandir}
rm -rf $RPM_BUILD_ROOT%{mingw32_docdir}/gnutls

rm -rf $RPM_BUILD_ROOT%{mingw64_infodir}
rm -rf $RPM_BUILD_ROOT%{mingw64_mandir}
rm -rf $RPM_BUILD_ROOT%{mingw64_docdir}/gnutls

# Remove test libraries
rm -f $RPM_BUILD_ROOT%{mingw32_libdir}/crypt32.dll*
rm -f $RPM_BUILD_ROOT%{mingw32_libdir}/ncrypt.dll*
rm -f $RPM_BUILD_ROOT%{mingw64_libdir}/crypt32.dll*
rm -f $RPM_BUILD_ROOT%{mingw64_libdir}/ncrypt.dll*


%files -n mingw32-gnutls
%license LICENSE doc/COPYING doc/COPYING.LESSER
%{mingw32_bindir}/certtool.exe
%{mingw32_bindir}/gnutls-cli-debug.exe
%{mingw32_bindir}/gnutls-cli.exe
%{mingw32_bindir}/gnutls-serv.exe
%{mingw32_bindir}/libgnutls-30.dll
%{mingw32_bindir}/ocsptool.exe
#{mingw32_bindir}/p11tool.exe
%{mingw32_bindir}/psktool.exe
#{mingw32_bindir}/srptool.exe
%{mingw32_libdir}/libgnutls.dll.a
%{mingw32_libdir}/libgnutls-30.def
%{mingw32_libdir}/pkgconfig/gnutls.pc
%{mingw32_includedir}/gnutls/

%files -n mingw64-gnutls
%license LICENSE doc/COPYING doc/COPYING.LESSER
%{mingw64_bindir}/certtool.exe
%{mingw64_bindir}/gnutls-cli-debug.exe
%{mingw64_bindir}/gnutls-cli.exe
%{mingw64_bindir}/gnutls-serv.exe
%{mingw64_bindir}/libgnutls-30.dll
%{mingw64_bindir}/ocsptool.exe
#{mingw64_bindir}/p11tool.exe
%{mingw64_bindir}/psktool.exe
#{mingw64_bindir}/srptool.exe
%{mingw64_libdir}/libgnutls.dll.a
%{mingw64_libdir}/libgnutls-30.def
%{mingw64_libdir}/pkgconfig/gnutls.pc
%{mingw64_includedir}/gnutls/




%changelog
* Tue Jul 01 2025 umeabot <umeabot> 3.8.7-2.mga10
+ Revision: 2232835
- Mageia 10 Mass Rebuild

* Wed Dec 25 2024 daviddavid <daviddavid> 3.8.7-1.mga10
+ Revision: 2129941
- new version: 3.8.7

* Mon Sep 26 2022 tv <tv> 3.7.7-3.mga9
+ Revision: 1892366
- Update to 3.7.7

* Tue Aug 02 2022 tv <tv> 3.7.1-3.mga9
+ Revision: 1874350
- Fix filelist
- BR bison + byacc

* Wed Mar 30 2022 umeabot <umeabot> 3.7.1-2.mga9
+ Revision: 1834734
- Mageia 9 Mass Rebuild

* Thu Apr 15 2021 daviddavid <daviddavid> 3.7.1-1.mga9
+ Revision: 1715855
- new version: 3.7.1

* Sat Sep 26 2020 tv <tv> 3.6.15-2.mga8
+ Revision: 1630238
- rebuild for new mingw stack

* Tue Sep 08 2020 daviddavid <daviddavid> 3.6.15-1.mga8
+ Revision: 1623634
- new version: 3.6.15

* Sat Jun 06 2020 daviddavid <daviddavid> 3.6.14-1.mga8
+ Revision: 1590670
- new version: 3.6.14

* Wed Apr 29 2020 daviddavid <daviddavid> 3.6.13-1.mga8
+ Revision: 1573250
- new version: 3.6.13

* Wed Feb 19 2020 umeabot <umeabot> 3.6.9-4.mga8
+ Revision: 1542851
- Mageia 8 Mass Rebuild

* Tue Jan 07 2020 daviddavid <daviddavid> 3.6.9-3.mga8
+ Revision: 1477099
- rebuild for new mingw-readline 8.0

* Tue Oct 01 2019 daviddavid <daviddavid> 3.6.9-2.mga8
+ Revision: 1448662
- rebuild for new migw-nettle 3.5.1

* Sun Aug 25 2019 daviddavid <daviddavid> 3.6.9-1.mga8
+ Revision: 1431995
- new version: 3.6.9

* Sat Jul 13 2019 daviddavid <daviddavid> 3.6.8-1.mga8
+ Revision: 1420889
- new version: 3.6.8

* Sun Feb 03 2019 daviddavid <daviddavid> 3.6.6-1.mga7
+ Revision: 1362908
- new version: 3.6.6
- remove merged upstream patches

* Thu Sep 20 2018 umeabot <umeabot> 3.6.3-2.mga7
+ Revision: 1279725
- Mageia 7 Mass Rebuild

* Wed Aug 29 2018 daviddavid <daviddavid> 3.6.3-1.mga7
+ Revision: 1255501
- new version: 3.6.3

* Tue Jun 26 2018 daviddavid <daviddavid> 3.6.2-1.mga7
+ Revision: 1239874
- new version: 3.6.2

* Wed May 11 2016 tv <tv> 3.4.11-1.mga6
+ Revision: 1012924
- new release
- rebuild for new mingw-nettle
- new release

* Mon Feb 08 2016 umeabot <umeabot> 3.1.11-9.mga6
+ Revision: 945194
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.1.11-8.mga5
+ Revision: 744188
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.11-7.mga5
+ Revision: 682443
- Mageia 5 Mass Rebuild

* Mon Sep 23 2013 neoclust <neoclust> 3.1.11-6.mga4
+ Revision: 483841
- imported package mingw-gnutls


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.11-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jun 17 2013 Kalev Lember <kalevlember@gmail.com> - 3.1.11-5
- One more rebuild for InterlockedCompareExchange

* Sun Jun 16 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.1.11-4
- Rebuild to resolve InterlockedCompareExchange regression in mingw32 libraries

* Sat Jun 15 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.1.11-3
- Fix FTBFS due to invalid use of cdecl

* Sat Jun 15 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.1.11-2
- Rebuild to resolve InterlockedCompareExchange regression in mingw32 libraries

* Thu May 30 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.11-1
- Update to 3.1.11

* Thu May 09 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.10-1
- Update to 3.1.10
- license of the library is back to LGPLv2.1+

* Mon Mar 04 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.8-1
- Update to 3.1.8
- Update No-ECC patch (#913797)

* Thu Feb 07 2013 Michael Cronenworth <mike@cchtml.com> - 3.1.7-1
- Update to 3.1.7

* Sun Jan 27 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.21-3
- Rebuild against mingw-gcc 4.8 (win64 uses SEH exceptions now)

* Thu Nov 22 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.21-2
- Rebuild against the latest mingw-readline

* Sat Nov 10 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.21-1
- Update to 2.12.21

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.12.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 19 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.20-1
- New upstream version.

* Sun May 20 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.19-1
- New upstream version.

* Sun May 13 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.18-1
- New upstream version.

* Thu Mar 29 2012 Michael Cronenworth <mike@cchtml.com> - 2.12.17-1
- New upstream version.
- Use system libtasn1.

* Sun Mar 11 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-7
- Added win64 support
- Dropped .def files

* Fri Mar 09 2012 Kalev Lember <kalevlember@gmail.com> - 2.12.14-6
- Remove .la files

* Wed Mar 07 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-5
- Renamed the source package to mingw-gnutls (RHBZ #800878)
- Use mingw macros without leading underscore
- Dropped unneeded RPM tags

* Tue Feb 28 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.12.14-4
- Rebuild against the mingw-w64 toolchain
- Fix compatibility with mingw-w64

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.12.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Dec 03 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.14-2
- Include new tool from p11-kit support.

* Sat Dec 03 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.14-1
- Update to 2.12.14
- Allow p11-kit support.

* Wed Nov 02 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.12-1
- Update to 2.12.12

* Mon Oct 24 2011 Michael Cronenworth <mike@cchtml.com> - 2.12.11-1
- Update to 2.12.11

* Wed Jul 06 2011 Kalev Lember <kalevlember@gmail.com> - 2.10.5-2
- Rebuilt against win-iconv

* Thu Apr 28 2011 Kalev Lember <kalev@smartlink.ee> - 2.10.5-1
- Update to 2.10.5

* Wed Apr 27 2011 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-7
- Dropped the proxy-libintl pieces

* Fri Apr 22 2011 Kalev Lember <kalev@smartlink.ee> - 2.6.4-6
- Rebuilt for pseudo-reloc version mismatch (#698827)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Nov  7 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-4
- Rebuild in order to have soft dependency on libintl

* Fri Oct  9 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 2.6.4-3
- Use %%global instead of %%define
- Automatically generate debuginfo subpackage

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar  9 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.4-1
- New Fedora native version 2.6.4.

* Fri Feb 20 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-5
- Rebuild for mingw32-gcc 4.4

* Thu Feb 19 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-4
- +BR mingw32-gcc-c++

* Fri Feb  6 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-3
- Include license.

* Fri Jan 23 2009 Richard W.M. Jones <rjones@redhat.com> - 2.6.3-2
- Rebase to native Fedora version 2.6.3.
- Enable C++ library.
- Use find_lang macro.
- Don't build static library.
- Rebase MinGW patch to 2.6.3.
- +BR mingw32-dlfcn.
- +BR mingw32-readline.
- Force rebuild of libtool.

* Tue Jan 13 2009 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-4
- Requires pkgconfig.

* Thu Nov 13 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-3
- fix chain verification issue CVE-2008-4989 (#470079)
- separate out the MinGW-specific patch from the others

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-2
- Rename mingw -> mingw32.

* Wed Sep 24 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.2-1
- New native version.

* Mon Sep 22 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-9
- Switch to source tar.bz2 with SRP stuff removed

* Sun Sep 21 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-8
- Remove duplicate manpages and info files.

* Thu Sep 11 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-7
- Add BR on autoconf, automake and libtool

* Wed Sep 10 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-6
- Need to run autoreconf after patching src/Makefile.am.
- Remove static libs.

* Fri Sep  5 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-5
- Add patch to build certtool.exe because of missing dep of gnulib on intl.
- BuildArch is noarch.

* Thu Sep  4 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-3
- Use mingw-filesystem RPM macros.
- Depends on mingw-iconv, mingw-gettext.

* Tue Sep  2 2008 Daniel P. Berrange <berrange@redhat.com> - 2.4.1-2
- List files explicitly and use custom CFLAGS

* Mon Jul  7 2008 Richard W.M. Jones <rjones@redhat.com> - 2.4.1-1
- Initial RPM release, largely based on earlier work from several sources.
